from PIL import Image

class FontGlyph:
    
    def __init__(self, pixels, size, offset, delta):
        self.pixels = pixels
        self.size = size
        self.offset = offset
        self.delta = delta
        
class Font:

    def __init__(self, glyphs):
        self.glyphs = glyphs
        
class FontPrinter:

    @staticmethod
    def print_text(image, position, str, font):
        (x, y) = position
        
        for c in str:
            code = ord(c)
            if code in font.glyphs:
                glyph = font.glyphs[code]
                
                glyphImage = Image.frombytes('1', glyph.size, glyph.pixels, 'raw', '1', 0, 1)
                (offX, offY) = glyph.offset
                target = (x + offX, y + offY)
                                
                image.paste(glyphImage, target)
                del glyphImage
                
                x = x + glyph.delta

        return (x, y)

    @staticmethod
    def measure(str, font):
        w = 0
        h = 0
        for c in str:
            code = ord(c)
            if code in font.glyphs:
                glyph = font.glyphs[code]
                w = w + glyph.delta
                (_, offY) = glyph.offset
                (_, sizeH) = glyph.size
                h = max(h, sizeH + offY)
        return (w, h)

class FontRepository:
    
    class SairaCondensed8:
        glyphs = {
            32: FontGlyph(b'\x80', (1, 1), (-1, 0), 3),
            33: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x80\x00', (1, 8), (0, 0), 3),
            34: FontGlyph(b'\x40\x40\x40', (3, 3), (0, 0), 4),
            35: FontGlyph(b'\xD0\xD0\x00\xA8\xA8\x00\xA8\xA8', (5, 8), (0, 0), 6),
            36: FontGlyph(b'\xA0\x00\x60\x20\xC0\xC0\x00\xA0', (3, 8), (0, 0), 4),
            37: FontGlyph(b'\xBA\x56\x56\x4A\xA4\xD4\xD4\xBA', (7, 8), (0, 0), 8),
            38: FontGlyph(b'\x08\x78\x78\xA0\x68\x68\x68\x08', (5, 8), (0, 0), 6),
            39: FontGlyph(b'\x00\x00\x00', (1, 3), (0, 0), 2),
            40: FontGlyph(b'\x80\x40\x40\x40\x40\x40\x40\x40\x40\x80', (2, 10), (0, -1), 3),
            41: FontGlyph(b'\x40\x80\x80\x80\x80\x80\x80\x80\x80\x40', (2, 10), (0, -1), 3),
            42: FontGlyph(b'\xA0\x40\x40\xA0', (3, 4), (0, 0), 4),
            43: FontGlyph(b'\xD8\xD8\x00\xD8\xD8', (5, 5), (0, 2), 6),
            44: FontGlyph(b'\x80\x80\x40', (2, 3), (0, 7), 3),
            45: FontGlyph(b'\x00', (3, 1), (0, 4), 4),
            46: FontGlyph(b'\x00', (1, 1), (0, 7), 2),
            47: FontGlyph(b'\xC0\xC0\xC0\xA0\xA0\xA0\xA0\x60\x60', (3, 9), (0, -1), 4),
            48: FontGlyph(b'\x90\x60\x60\x60\x60\x60\x60\x90', (4, 8), (0, 0), 5),
            49: FontGlyph(b'\x80\x00\x80\x80\x80\x80\x80\x80', (2, 8), (0, 0), 3),
            50: FontGlyph(b'\x90\x60\xE0\xE0\x90\x70\x70\x00', (4, 8), (0, 0), 5),
            51: FontGlyph(b'\x10\xE0\xE0\x90\xE0\xE0\xE0\x10', (4, 8), (0, 0), 5),
            52: FontGlyph(b'\xD8\xD8\xA8\xA8\xA8\x00\xE8\xE8', (5, 8), (0, 0), 6),
            53: FontGlyph(b'\x00\x60\x60\x20\xC0\xC0\xC0\x20', (3, 8), (0, 0), 4),
            54: FontGlyph(b'\x90\x70\x70\x10\x60\x60\x60\x90', (4, 8), (0, 0), 5),
            55: FontGlyph(b'\x00\xE0\xE0\xD0\xD0\xD0\xB0\xB0', (4, 8), (0, 0), 5),
            56: FontGlyph(b'\x90\x60\x60\x90\x60\x60\x60\x90', (4, 8), (0, 0), 5),
            57: FontGlyph(b'\x90\x60\x60\x60\x80\xE0\xE0\x90', (4, 8), (0, 0), 5),
            58: FontGlyph(b'\x00\x80\x80\x80\x80\x00', (1, 6), (0, 2), 2),
            59: FontGlyph(b'\x80\xC0\xC0\xC0\xC0\x80\x80\x40', (2, 8), (-1, 2), 2),
            60: FontGlyph(b'\xE0\x90\x70\x90\xE0', (4, 5), (0, 3), 5),
            61: FontGlyph(b'\x00\xF0\x00', (4, 3), (0, 4), 5),
            62: FontGlyph(b'\x70\x90\xE0\x90\x70', (4, 5), (0, 3), 5),
            63: FontGlyph(b'\x00\xC0\xC0\xC0\xA0\xA0\xE0\xA0', (3, 8), (0, 0), 4),
            64: FontGlyph(b'\x82\x7C\x44\x74\x44\x54\x48\x7E\xBE\xC6', (7, 10), (0, 0), 8),
            65: FontGlyph(b'\xD8\xD8\xA8\xA8\xA8\x80\x70\x70', (5, 8), (0, 0), 6),
            66: FontGlyph(b'\x10\x60\x60\x10\x60\x60\x60\x10', (4, 8), (0, 0), 5),
            67: FontGlyph(b'\x80\x60\x60\x60\x60\x60\x60\x80', (3, 8), (0, 0), 4),
            68: FontGlyph(b'\x10\x60\x60\x60\x60\x60\x60\x10', (4, 8), (0, 0), 5),
            69: FontGlyph(b'\x00\x60\x60\x00\x60\x60\x60\x00', (3, 8), (0, 0), 4),
            70: FontGlyph(b'\x00\x60\x60\x60\x00\x60\x60\x60', (3, 8), (0, 0), 4),
            71: FontGlyph(b'\x80\x70\x70\x70\x40\x60\x60\x80', (4, 8), (0, 0), 5),
            72: FontGlyph(b'\x60\x60\x60\x00\x60\x60\x60\x60', (4, 8), (0, 0), 5),
            73: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00', (1, 8), (0, 0), 2),
            74: FontGlyph(b'\x80\x80\x80\x80\x80\x80\x80\x00', (2, 8), (-1, 0), 2),
            75: FontGlyph(b'\x60\x50\x50\x30\x50\x50\x60\x60', (4, 8), (0, 0), 5),
            76: FontGlyph(b'\x60\x60\x60\x60\x60\x60\x60\x00', (3, 8), (0, 0), 4),
            77: FontGlyph(b'\x38\x38\x38\x54\x54\x54\x6C\x6C', (7, 8), (0, 0), 8),
            78: FontGlyph(b'\x60\x60\x20\x20\x40\x40\x60\x60', (4, 8), (0, 0), 5),
            79: FontGlyph(b'\x90\x60\x60\x60\x60\x60\x60\x90', (4, 8), (0, 0), 5),
            80: FontGlyph(b'\x10\x60\x60\x60\x10\x70\x70\x70', (4, 8), (0, 0), 5),
            81: FontGlyph(b'\x90\x60\x60\x60\x60\x20\x40\x90\xE0', (4, 9), (0, 0), 5),
            82: FontGlyph(b'\x10\x60\x60\x60\x10\x50\x60\x60', (4, 8), (0, 0), 5),
            83: FontGlyph(b'\x80\x70\x70\x90\xE0\xE0\xE0\x10', (4, 8), (0, 0), 5),
            84: FontGlyph(b'\x00\xD8\xD8\xD8\xD8\xD8\xD8\xD8', (5, 8), (0, 0), 6),
            85: FontGlyph(b'\x60\x60\x60\x60\x60\x60\x60\x90', (4, 8), (0, 0), 5),
            86: FontGlyph(b'\x70\x70\xA8\xA8\xA8\xA8\xD8\xD8', (5, 8), (0, 0), 6),
            87: FontGlyph(b'\x7C\x6C\x6C\x54\x54\x54\xBA\xBA', (7, 8), (0, 0), 8),
            88: FontGlyph(b'\x70\xA8\xA8\xD8\xD8\xA8\xA8\x70', (5, 8), (0, 0), 6),
            89: FontGlyph(b'\x70\xA8\xA8\xD8\xD8\xD8\xD8\xD8', (5, 8), (0, 0), 6),
            90: FontGlyph(b'\x00\xE0\xD0\xD0\xD0\xB0\xB0\x00', (4, 8), (0, 0), 5),
            91: FontGlyph(b'\x00\x40\x40\x40\x40\x40\x40\x40\x40\x40\x00', (2, 11), (0, -1), 3),
            92: FontGlyph(b'\x60\x60\xA0\xA0\xA0\xA0\xC0\xC0\xC0', (3, 9), (0, -1), 4),
            93: FontGlyph(b'\x00\x80\x80\x80\x80\x80\x80\x80\x80\x80\x00', (2, 11), (0, -1), 3),
            94: FontGlyph(b'\xD8\xA8\x70', (5, 3), (0, -1), 6),
            95: FontGlyph(b'\x00', (3, 1), (0, 9), 4),
            96: FontGlyph(b'\x00\x00', (1, 2), (0, -1), 2),
            97: FontGlyph(b'\x80\xE0\x80\x60\x60\x80', (4, 6), (0, 2), 5),
            98: FontGlyph(b'\x70\x70\x70\x10\x60\x60\x60\x60\x10', (4, 9), (0, -1), 5),
            99: FontGlyph(b'\x00\x40\x40\x40\x40\x00', (2, 6), (0, 2), 3),
            100: FontGlyph(b'\xE0\xE0\xE0\x80\x60\x60\x60\x60\x80', (4, 9), (0, -1), 5),
            101: FontGlyph(b'\xA0\x40\x00\x60\x60\x80', (3, 6), (0, 2), 4),
            102: FontGlyph(b'\x80\xA0\xA0\x00\xA0\xA0\xA0\xA0\xA0', (3, 9), (0, -1), 4),
            103: FontGlyph(b'\x00\x40\x40\x40\x40\x00\xC0\x00', (3, 8), (0, 2), 4),
            104: FontGlyph(b'\x60\x60\x60\x00\x40\x40\x40\x40\x40', (3, 9), (0, -1), 4),
            105: FontGlyph(b'\x00\x80\x80\x00\x00\x00\x00\x00\x00', (1, 9), (0, -1), 2),
            106: FontGlyph(b'\x80\xC0\xC0\x80\x80\x80\x80\x80\x80\x80\x40', (2, 11), (-1, -1), 2),
            107: FontGlyph(b'\x60\x60\x60\x40\x40\x20\x20\x20\x40', (3, 9), (0, -1), 4),
            108: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00', (1, 9), (0, -1), 2),
            109: FontGlyph(b'\x28\x50\x50\x50\x50\x50', (5, 6), (0, 2), 6),
            110: FontGlyph(b'\x20\x40\x40\x40\x40\x40', (3, 6), (0, 2), 4),
            111: FontGlyph(b'\x00\x40\x40\x40\x40\x00', (3, 6), (0, 2), 4),
            112: FontGlyph(b'\x00\x40\x40\x40\x40\x00\x60\x60', (3, 8), (0, 2), 4),
            113: FontGlyph(b'\x00\x40\x40\x40\x40\x00\xC0\xC0', (3, 8), (0, 2), 4),
            114: FontGlyph(b'\x00\x40\x40\x40\x40\x40', (2, 6), (0, 2), 3),
            115: FontGlyph(b'\x80\x70\xB0\xD0\xE0\x10', (4, 6), (0, 2), 5),
            116: FontGlyph(b'\xA0\xA0\x00\xA0\xA0\xA0\xA0\xA0', (3, 8), (0, 0), 4),
            117: FontGlyph(b'\x40\x40\x40\x40\x40\x00', (3, 6), (0, 2), 4),
            118: FontGlyph(b'\x40\x40\x40\xA0\xA0\xA0', (3, 6), (0, 2), 4),
            119: FontGlyph(b'\x6C\xAA\xAA\x92\xD6\xD6', (7, 6), (0, 2), 8),
            120: FontGlyph(b'\x40\x40\xA0\xA0\x40\x40', (3, 6), (0, 2), 4),
            121: FontGlyph(b'\x40\x40\x40\x40\x40\x00\xC0\x00', (3, 8), (0, 2), 4),
            122: FontGlyph(b'\x00\xD0\xD0\xB0\xB0\x00', (4, 6), (0, 2), 5),
            123: FontGlyph(b'\xD8\xD8\x88\x88\x00\x50\xD8\xD8\xD8\xD8', (5, 10), (0, -1), 6),
            124: FontGlyph(b'\xFF\x80\xBE\x80\x00\x00\x00\x00\x7F\x00\x55\x00\x7F\x00\x55\x00\x7F\x00\x7F\x00\x00\x00', (9, 11), (0, -2), 10),
            125: FontGlyph(b'\xD8\xD8\xD8\xD8\x50\x00\x88\x88\xD8\xD8', (5, 10), (0, 0), 6),
            126: FontGlyph(b'\xA0\x50', (4, 2), (0, 3), 5)
        }

    class SairaCondensed11:
            glyphs = {
            32: FontGlyph(b'\x80', (1, 1), (1, 0), 4),
            33: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\xC0\xC0\x00', (2, 13), (0, 0), 6),
            34: FontGlyph(b'\x20\x20\x20\x20\x20', (5, 5), (0, 0), 6),
            35: FontGlyph(b'\xE4\x80\xE4\x80\xE4\x80\x00\x00\xC9\x80\xC9\x80\xC9\x80\xC9\x80\x00\x00\x93\x80\x93\x80\x93\x80\x93\x80', (9, 13), (0, 0), 10),
            36: FontGlyph(b'\xE4\xE4\x80\x3C\x3C\x3C\x84\xF0\xF0\xF0\x04\xCC\xCC', (6, 13), (0, 0), 8),
            37: FontGlyph(b'\x8F\x20\x26\x60\x26\x60\x24\xE0\x24\xE0\x21\xE0\x88\x20\xF0\x80\xF0\x80\xE4\x80\xE4\x80\xCC\x80\xCE\x20', (11, 13), (0, 0), 12),
            38: FontGlyph(b'\x81\x80\x3F\x80\x3F\x80\x3F\x80\x3F\x80\x9F\x80\xC4\x00\x1C\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x80\x80', (9, 13), (0, 0), 10),
            39: FontGlyph(b'\x00\x00\x00\x00\x00', (2, 5), (0, 0), 3),
            40: FontGlyph(b'\xE0\xD0\x90\x90\x30\x30\x30\x30\x30\x30\x30\x30\x30\x90\x90\xD0\xE0', (4, 17), (0, -1), 5),
            41: FontGlyph(b'\x70\xB0\x90\x90\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x90\x90\xB0\x70', (4, 17), (0, -1), 5),
            42: FontGlyph(b'\xCC\x48\x84\x84\x48\xCC', (6, 6), (0, 0), 7),
            43: FontGlyph(b'\xE7\xE7\xE7\x00\xE7\xE7\xE7', (8, 7), (0, 5), 8),
            44: FontGlyph(b'\x00\x80\x80', (3, 3), (0, 12), 3),
            45: FontGlyph(b'\x00', (4, 1), (0, 7), 5),
            46: FontGlyph(b'\x00', (2, 1), (0, 12), 3),
            47: FontGlyph(b'\xF0\xF0\xF0\xE4\xE4\xE4\xE4\xCC\xCC\xCC\xCC\x9C\x9C\x9C\x3C', (6, 15), (-1, -1), 5),
            48: FontGlyph(b'\xC3\x99\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x99\xC3', (8, 13), (0, 0), 9),
            49: FontGlyph(b'\x80\x00\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80', (3, 13), (0, 0), 4),
            50: FontGlyph(b'\x02\xF8\xF8\xF8\xF8\xF2\xC6\x9E\x3E\x3E\x3E\x3E\x00', (7, 13), (0, 0), 8),
            51: FontGlyph(b'\x02\xF8\xF8\xF8\xF8\xF2\xC6\xF2\xF8\xF8\xF8\xF8\x02', (7, 13), (0, 0), 8),
            52: FontGlyph(b'\xE7\xE7\xCF\xCF\x99\x99\x99\x39\x39\x00\xF9\xF9\xF9', (8, 13), (0, 0), 9),
            53: FontGlyph(b'\x02\x3E\x3E\x3E\x3E\x02\xF8\xF8\xF8\xF8\xF8\xF8\x02', (7, 13), (0, 0), 8),
            54: FontGlyph(b'\xC1\x9F\x3F\x3F\x3F\x01\x3C\x3C\x3C\x3C\x3C\x3C\x81', (8, 13), (0, 0), 9),
            55: FontGlyph(b'\x00\xF8\xF8\xF8\xF2\xF2\xF2\xE6\xE6\xE6\xCE\xCE\xCE', (7, 13), (0, 0), 8),
            56: FontGlyph(b'\x81\x3C\x3C\x3C\x3C\x9D\xC3\xB9\x3C\x3C\x3C\x3C\x81', (8, 13), (0, 0), 9),
            57: FontGlyph(b'\x81\x3C\x3C\x3C\x3C\x3C\x80\xFC\xFC\xFC\xFC\xFC\x01', (8, 13), (0, 0), 9),
            58: FontGlyph(b'\x00\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x00', (2, 10), (0, 3), 3),
            59: FontGlyph(b'\x00\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x00\x80\x80', (2, 12), (0, 3), 3),
            60: FontGlyph(b'\xFC\xF0\xCE\x1E\x1E\xCE\xF0\xFC', (7, 8), (0, 4), 8),
            61: FontGlyph(b'\x00\xFE\xFE\x00', (7, 4), (0, 6), 9),
            62: FontGlyph(b'\x7E\x1E\xE6\xF0\xF0\xE6\x1E\x7E', (7, 8), (0, 4), 8),
            63: FontGlyph(b'\x04\xF0\xF0\xF0\xF0\xE4\xCC\xCC\xCC\xCC\xFC\xFC\xCC', (6, 13), (0, 0), 7),
            64: FontGlyph(b'\xC0\x30\xBF\xC0\x3F\xC0\x30\xC0\x3E\x40\x3E\x40\x3E\x40\x30\x40\x26\x40\x26\x40\x26\x40\x30\x30\x3F\xF0\xBF\xF0\xC0\x70', (12, 15), (0, 0), 13),
            65: FontGlyph(b'\xF3\xC0\xF3\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xCC\xC0\xCC\xC0\xCC\xC0\xC0\xC0\x9E\x40\x9E\x40\x3F\x00\x3F\x00', (10, 13), (0, 0), 11),
            66: FontGlyph(b'\x03\x3D\x3C\x3C\x3C\x3D\x03\x3D\x3C\x3C\x3C\x3C\x01', (8, 13), (0, 0), 9),
            67: FontGlyph(b'\xC0\x9C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x9C\xC0', (6, 13), (0, 0), 7),
            68: FontGlyph(b'\x03\x3D\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3D\x03', (8, 13), (0, 0), 9),
            69: FontGlyph(b'\x00\x3E\x3E\x3E\x3E\x3E\x02\x3E\x3E\x3E\x3E\x3E\x00', (7, 13), (0, 0), 8),
            70: FontGlyph(b'\x00\x3E\x3E\x3E\x3E\x3E\x02\x3E\x3E\x3E\x3E\x3E\x3E', (7, 13), (0, 0), 8),
            71: FontGlyph(b'\xC0\xBF\x3F\x3F\x3F\x3F\x30\x3C\x3C\x3C\x3C\xBC\xC0', (8, 13), (0, 0), 9),
            72: FontGlyph(b'\x3C\x3C\x3C\x3C\x3C\x3C\x00\x3C\x3C\x3C\x3C\x3C\x3C', (8, 13), (0, 0), 9),
            73: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (2, 13), (0, 0), 3),
            74: FontGlyph(b'\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x10', (4, 13), (0, 0), 5),
            75: FontGlyph(b'\x3C\x39\x39\x33\x33\x37\x0F\x37\x33\x33\x39\x39\x3C', (8, 13), (0, 0), 9),
            76: FontGlyph(b'\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x00', (6, 13), (0, 0), 7),
            77: FontGlyph(b'\x3F\xC0\x1F\x80\x1F\x80\x0F\x00\x0F\x00\x26\x40\x26\x40\x26\x40\x30\xC0\x30\xC0\x39\xC0\x39\xC0\x39\xC0', (12, 13), (0, 0), 13),
            78: FontGlyph(b'\x3C\x1C\x1C\x0C\x0C\x24\x24\x24\x30\x30\x30\x38\x38', (8, 13), (0, 0), 9),
            79: FontGlyph(b'\x81\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x81', (8, 13), (0, 0), 9),
            80: FontGlyph(b'\x01\x3C\x3C\x3C\x3C\x3C\x3C\x01\x3F\x3F\x3F\x3F\x3F', (8, 13), (0, 0), 9),
            81: FontGlyph(b'\x81\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x3C\x80\x24\x80\x30\x80\x38\x80\x81\x80\xFC\x80\xFE\x00', (9, 15), (0, 0), 10),
            82: FontGlyph(b'\x01\x3C\x3C\x3C\x3C\x3C\x01\x3B\x39\x39\x39\x3C\x3C', (8, 13), (0, 0), 9),
            83: FontGlyph(b'\x80\x3E\x3E\x3E\x3E\x3E\x82\xF8\xF8\xF8\xF8\xF8\x02', (7, 13), (0, 0), 8),
            84: FontGlyph(b'\x00\xE7\xE7\xE7\xE7\xE7\xE7\xE7\xE7\xE7\xE7\xE7\xE7', (8, 13), (0, 0), 9),
            85: FontGlyph(b'\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\x3C\xBD\xC3', (8, 13), (0, 0), 9),
            86: FontGlyph(b'\x3E\x00\x3E\x00\x9C\x80\x9C\x80\x9C\x80\x9C\x80\xC9\x80\xC9\x80\xC9\x80\xE3\x80\xE3\x80\xF7\x80\xF7\x80', (9, 13), (0, 0), 10),
            87: FontGlyph(b'\x3C\xF0\x3C\xF0\x9C\xE4\x9C\xE4\x98\x64\x98\x64\xC8\x4C\xC3\x0C\xC3\x0C\xC7\x8C\xC7\x8C\xE7\x9C\xE7\x9C', (14, 13), (0, 0), 15),
            88: FontGlyph(b'\x3E\x00\x9C\x80\x9C\x80\x9C\x80\xC9\x80\xE3\x80\xE3\x80\xE3\x80\xC9\x80\x9C\x80\x9C\x80\x9C\x80\x3E\x00', (9, 13), (0, 0), 10),
            89: FontGlyph(b'\x7E\x3C\x3C\x99\x99\x99\xC3\xE7\xE7\xE7\xE7\xE7\xE7', (8, 13), (0, 0), 9),
            90: FontGlyph(b'\x00\xF8\xF2\xF2\xE6\xE6\xCE\xCE\xCE\x9E\x9E\x3E\x00', (7, 13), (0, 0), 8),
            91: FontGlyph(b'\x00\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x00', (3, 17), (0, -1), 4),
            92: FontGlyph(b'\x38\x38\x38\x98\x98\x98\x98\x98\x98\xC8\xC8\xC8\xE0\xE0\xE0', (5, 15), (0, -1), 6),
            93: FontGlyph(b'\x00\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x00', (3, 17), (0, -1), 4),
            94: FontGlyph(b'\xEE\xEE\xC6\x92\x92\x38', (7, 6), (0, -2), 8),
            95: FontGlyph(b'\x00', (6, 1), (-1, 15), 6),
            96: FontGlyph(b'\x20\xA0\xC0', (3, 3), (0, -1), 4),
            97: FontGlyph(b'\x04\xF0\xF0\xF0\x80\x30\x30\x30\x30\x08', (6, 10), (0, 3), 7),
            98: FontGlyph(b'\x7E\x7E\x7E\x7E\x02\x38\x38\x38\x38\x38\x38\x38\x38\x02', (7, 14), (0, -1), 8),
            99: FontGlyph(b'\x80\x38\x38\x38\x38\x38\x38\x38\x38\x80', (5, 10), (0, 3), 6),
            100: FontGlyph(b'\xF8\xF8\xF8\xF8\x80\x38\x38\x38\x38\x38\x38\x38\x38\x80', (7, 14), (0, -1), 8),
            101: FontGlyph(b'\x82\x38\x38\x38\x00\x3E\x3E\x3E\x3E\x82', (7, 10), (0, 3), 8),
            102: FontGlyph(b'\xE0\xCC\xCC\xCC\x00\xCC\xCC\xCC\xCC\xCC\xCC\xCC\xCC\xCC', (6, 14), (0, -1), 7),
            103: FontGlyph(b'\x80\x38\x38\x38\x38\x38\x38\x38\x38\x80\xF8\xF8\xFA\x06', (7, 14), (0, 3), 8),
            104: FontGlyph(b'\x3E\x3E\x3E\x3E\x02\x38\x38\x38\x38\x38\x38\x38\x38\x38', (7, 14), (0, -1), 8),
            105: FontGlyph(b'\x00\xC0\xC0\xC0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (2, 14), (0, -1), 3),
            106: FontGlyph(b'\x80\xE0\xE0\xE0\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x80\x20', (3, 18), (-1, -1), 3),
            107: FontGlyph(b'\x3E\x3E\x3E\x3E\x3C\x38\x32\x26\x0E\x1E\x0E\x26\x32\x38', (7, 14), (0, -1), 8),
            108: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (2, 14), (0, -1), 3),
            109: FontGlyph(b'\x02\x10\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0', (12, 10), (0, 3), 13),
            110: FontGlyph(b'\x02\x38\x38\x38\x38\x38\x38\x38\x38\x38', (7, 10), (0, 3), 8),
            111: FontGlyph(b'\x82\x38\x38\x38\x38\x38\x38\x38\x38\x82', (7, 10), (0, 3), 8),
            112: FontGlyph(b'\x02\x38\x38\x38\x38\x38\x38\x38\x38\x02\x3E\x3E\x3E\x3E', (7, 14), (0, 3), 8),
            113: FontGlyph(b'\x80\x38\x38\x38\x38\x38\x38\x38\x38\x80\xF8\xF8\xF8\xF8', (7, 14), (0, 3), 8),
            114: FontGlyph(b'\x80\x30\x30\x30\x30\x30\x30\x30\x30\x30', (4, 10), (0, 3), 5),
            115: FontGlyph(b'\x80\x3C\x3C\x3C\x84\xF0\xF0\xF0\xF0\x04', (6, 10), (0, 3), 7),
            116: FontGlyph(b'\xCC\xCC\xCC\x00\xCC\xCC\xCC\xCC\xCC\xCC\xCC\xCC\xCC', (6, 13), (0, 0), 7),
            117: FontGlyph(b'\x38\x38\x38\x38\x38\x38\x38\x38\x38\x84', (7, 10), (0, 3), 8),
            118: FontGlyph(b'\x38\x38\x38\x38\x38\x38\x92\x92\xC6\xEE', (7, 10), (0, 3), 8),
            119: FontGlyph(b'\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x39\xC0\x99\x90\x99\x90\x90\x90\x90\x90\xC6\x30', (12, 10), (0, 3), 13),
            120: FontGlyph(b'\x7C\x38\x92\x92\xC6\xC6\x92\x92\x38\x7C', (7, 10), (0, 3), 8),
            121: FontGlyph(b'\x38\x38\x38\x38\x38\x38\x38\x38\x38\x80\xF8\xF8\xF2\x06', (7, 14), (0, 3), 8),
            122: FontGlyph(b'\x00\xF0\xE4\xCC\xCC\x9C\x3C\x3C\x3C\x00', (6, 10), (0, 3), 7),
            123: FontGlyph(b'\xFF\xFE\xFF\xEE\xDF\xDE\xBC\xFE\xF8\xFE\xF1\xEE\xE1\xCE\xC3\x9E\xC3\x1E\xE7\xBE\xFD\xFE\xF9\xFE\xF3\xDE\xE3\xBE\xF7\xFE\xFF\xFE', (15, 16), (0, -1), 17),
            124: FontGlyph(b'\xFF\xFF\xFE\xFF\xBE\xFB\xDF\xF7\xF0\x1F\xE0\x0F\xEA\xAF\xEA\xAF\x2A\xA9\xEA\x4F\xEE\x4F\xE0\x0F\xF0\x1F\xDF\xF7\xBE\xFB\xFE\xFF', (16, 16), (0, -1), 18),
            125: FontGlyph(b'\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xE3\xFF\xDD\x1F\xBE\xE7\xBF\x7B\x7F\xFD\x7F\xFD\x7F\xFD\xBF\xFB\xC0\x07\xFF\xFF\xFF\xFF\xFF\xFF', (16, 16), (0, -1), 18),
            126: FontGlyph(b'\xFF\xFF\xFF\xFF\xFF\xFF\xFC\x3F\xFD\xBF\xFA\x5F\xF7\xEF\xF6\x6F\xEE\x77\xEF\xF7\xDF\xFB\xDE\x7B\xBE\x7D\xBE\x7D\xFF\xFF\xFF\xFF', (16, 16), (0, -1), 18)
        }

    class SairaCondensed22:
        glyphs = {
            32: FontGlyph(b'\x80', (1, 1), (2, 0), 8),
            33: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x90\x90\x90\x90\xF0\xF0\xF0\x00\x00\x00', (4, 20), (1, 0), 8),
            34: FontGlyph(b'\x08\x00\x08\x00\x08\x00\x08\x00\x8C\x00\x8C\x00\x8C\x00', (9, 7), (0, 0), 10),
            35: FontGlyph(b'\xF1\x8C\xF1\x8C\xF1\x8C\xF1\x8C\xF1\x8C\xF1\x8C\x80\x00\x80\x00\xE3\x1C\xE3\x1C\xE3\x1C\xE3\x1C\xE3\x1C\x00\x04\x00\x04\xC6\x3C\xC6\x3C\xC6\x3C\xC6\x3C\xC6\x3C', (14, 20), (0, 0), 15),
            36: FontGlyph(b'\xF1\xE0\xF1\xE0\xC0\x20\x80\x20\x8F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x83\xE0\x80\x60\xC0\x20\xFC\x00\xFE\x00\xFE\x00\xFE\x00\xFC\x20\x80\x20\x80\x60\xF1\xE0\xF1\xE0', (11, 20), (0, 0), 12),
            37: FontGlyph(b'\x81\xF1\xC0\x81\xF1\xC0\x18\xE3\xC0\x18\xE3\xC0\x18\xC7\xC0\x18\xC7\xC0\x18\x8F\xC0\x18\x8F\xC0\x18\x1F\xC0\x80\x00\x40\x80\x20\x40\xFE\x06\x00\xFC\x46\x00\xFC\x46\x00\xF8\xC6\x00\xF8\xC6\x00\xF1\xC6\x00\xF1\xC6\x00\xF3\xE0\x40\xE3\xE0\x40', (18, 20), (0, 0), 19),
            38: FontGlyph(b'\xE0\x0E\xC0\x06\x83\xE6\x8F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x8F\xFE\x87\xFE\xC0\x80\xC0\x80\x87\x86\x8F\x86\x0F\x86\x0F\x86\x0F\x86\x0F\x86\x87\x86\x80\x06\xE0\x06', (15, 20), (0, 0), 15),
            39: FontGlyph(b'\x00\x00\x00\x00\x80\x80\x80', (4, 7), (0, 0), 8),
            40: FontGlyph(b'\xE0\xC4\xC4\x8C\x8C\x0C\x0C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x0C\x0C\x8C\x8C\xC4\xC4\xE0', (6, 26), (0, -2), 8),
            41: FontGlyph(b'\x1C\x8C\x8C\xC4\xC4\xC0\xC0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xC4\xC4\x8C\x8C\x1C', (6, 26), (0, -2), 8),
            42: FontGlyph(b'\xE3\x80\xE3\x80\x22\x00\x00\x00\xC1\x80\xC1\x80\x00\x00\x22\x00\xE3\x80\xE3\x80', (9, 10), (0, 0), 11),
            43: FontGlyph(b'\xF1\xE0\xF1\xE0\xF1\xE0\xF1\xE0\x00\x00\x00\x00\xF1\xE0\xF1\xE0\xF1\xE0\xF1\xE0', (11, 10), (1, 8), 14),
            44: FontGlyph(b'\x80\x80\x80\xC0\xC0\x08', (5, 6), (0, 17), 8),
            45: FontGlyph(b'\x00\x00', (6, 2), (0, 11), 8),
            46: FontGlyph(b'\x00\x00\x00', (4, 3), (1, 17), 8),
            47: FontGlyph(b'\xF8\xF8\xF0\xF1\xF1\xF1\xE1\xE3\xE3\xE3\xC3\xC3\xC7\xC7\x87\x87\x8F\x8F\x8F\x0F\x1F\x1F\x1F', (8, 23), (0, -2), 8),
            48: FontGlyph(b'\xE0\x38\xC0\x18\x87\x08\x87\x08\x8F\x88\x8F\x88\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x8F\x88\x8F\x88\x87\x08\x87\x08\xC0\x18\xE0\x38', (13, 20), (0, 0), 15),
            49: FontGlyph(b'\xC0\x80\x00\x00\x20\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0', (6, 20), (0, 0), 8),
            50: FontGlyph(b'\x80\x60\x80\x00\x9E\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFE\x00\xFC\x00\xF8\x20\xE0\x60\x80\xE0\x83\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x00\x00\x00\x00', (11, 20), (0, 0), 13),
            51: FontGlyph(b'\x00\x60\x00\x20\x3C\x20\xFE\x00\xFE\x00\xFE\x00\xFE\x00\xFE\x00\xFC\x20\xC0\x60\xC0\x20\xFE\x20\xFE\x00\xFE\x00\xFE\x00\xFE\x00\xFE\x00\x3C\x00\x00\x20\x00\x60', (11, 20), (0, 0), 13),
            52: FontGlyph(b'\xF8\x78\xF0\xF8\xF0\xF8\xE1\xF8\xE1\xF8\xE1\xF8\xC3\x18\xC3\x18\xC6\x18\x86\x18\x86\x18\x0E\x18\x0E\x18\x00\x00\x00\x00\xFE\x18\xFE\x18\xFE\x18\xFE\x18\xFE\x18', (13, 20), (0, 0), 15),
            53: FontGlyph(b'\x00\x20\x00\x20\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x00\x60\x00\x20\xFC\x20\xFE\x00\xFE\x00\xFE\x00\xFE\x00\xFE\x00\xFE\x20\xFC\x20\x00\x20\x00\xE0', (11, 20), (0, 0), 13),
            54: FontGlyph(b'\xE0\x08\xC0\x08\x83\xC8\x87\xF8\x8F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x00\x18\x00\x08\x07\x08\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x8F\x80\x8F\x80\x87\x08\xC0\x08\xE0\x18', (13, 20), (0, 0), 15),
            55: FontGlyph(b'\x00\x00\x00\x00\xFE\x00\xFE\x00\xFC\x20\xFC\x20\xFC\x20\xF8\x60\xF8\x60\xF8\x60\xF0\xE0\xF0\xE0\xF0\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xC3\xE0\xC3\xE0\xC3\xE0\x87\xE0', (11, 20), (0, 0), 13),
            56: FontGlyph(b'\xE0\x38\x80\x08\x87\x08\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x8F\x88\x87\x08\xC0\x18\xC0\x08\x87\x08\x8F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x87\x08\x80\x08\xE0\x38', (13, 20), (0, 0), 15),
            57: FontGlyph(b'\xC0\x38\x80\x18\x87\x08\x0F\x88\x0F\x88\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x87\x00\x80\x00\xC0\x00\xFF\x80\xFF\x80\xFF\x88\xFF\x08\xFF\x08\x3E\x18\x00\x18\x80\x78', (13, 20), (0, 0), 15),
            58: FontGlyph(b'\x00\x00\x00\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\x00\x00\x00', (4, 15), (1, 5), 8),
            59: FontGlyph(b'\x80\x80\x80\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\x80\x80\x80\xC0\xC0\x08', (5, 18), (0, 5), 8),
            60: FontGlyph(b'\xFF\x80\xFE\x00\xF8\x00\xC0\x60\x03\xE0\x0F\xE0\x07\xE0\x80\xE0\xF0\x20\xFC\x00\xFF\x80', (11, 11), (0, 7), 13),
            61: FontGlyph(b'\x00\x00\x00\x00\xFF\xE0\xFF\xE0\xFF\xE0\x00\x00\x00\x00', (11, 7), (1, 9), 14),
            62: FontGlyph(b'\x3F\xE0\x0F\xE0\x03\xE0\xC0\x60\xF8\x00\xFE\x00\xFC\x00\xE0\x20\x81\xE0\x07\xE0\x3F\xE0', (11, 11), (1, 7), 14),
            63: FontGlyph(b'\x01\x80\x00\x00\x38\x00\xF8\x00\xFC\x00\xFC\x00\xF8\x00\xF8\x00\xF0\x00\xC0\x80\xC3\x80\xC7\x80\xC7\x80\xC7\x80\xFF\x80\xFF\x80\xFF\x80\xC7\x80\xC7\x80\xC7\x80', (9, 20), (0, 0), 10),
            64: FontGlyph(b'\xE0\x03\x80\x80\x00\x80\x9F\xFC\x80\x1F\xFC\x00\x3F\xFE\x00\x38\x0E\x00\x38\x06\x00\x3F\x86\x00\x3F\xC6\x00\x3F\xC6\x00\x3F\xC6\x00\x38\x06\x00\x30\x06\x00\x31\xC6\x00\x31\xC6\x00\x31\x86\x00\x30\x04\x00\x38\x00\x80\x3F\xFF\x80\x1F\xFF\x80\x1F\xFF\x80\x80\x07\x80\xC0\x07\x80', (17, 23), (0, 0), 19),
            65: FontGlyph(b'\xF8\x3E\xF8\x3E\xF8\x1E\xF0\x1E\xF0\x1E\xF0\x1E\xF1\x0E\xE1\x0E\xE1\x0E\xE1\x0E\xE3\x86\xC3\x86\xC3\x86\xC0\x06\xC0\x02\xC7\xC2\x87\xC2\x87\xE2\x0F\xE0\x0F\xE0', (15, 20), (-1, 0), 16),
            66: FontGlyph(b'\x00\x30\x00\x10\x0E\x10\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x10\x0E\x10\x00\x30\x00\x30\x0E\x10\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0E\x00\x00\x10\x00\x30', (12, 20), (0, 0), 14),
            67: FontGlyph(b'\xE0\x00\xC0\x00\x83\xE0\x87\xE0\x8F\xE0\x8F\xE0\x8F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x8F\xE0\x8F\xE0\x8F\xE0\x87\xE0\x83\xE0\xC0\x00\xE0\x00', (11, 20), (0, 0), 13),
            68: FontGlyph(b'\x00\x70\x00\x10\x0E\x10\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0E\x10\x00\x10\x00\x70', (12, 20), (0, 0), 14),
            69: FontGlyph(b'\x00\x00\x00\x00\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x00\x40\x00\x40\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x00\x00\x00\x00', (10, 20), (0, 0), 12),
            70: FontGlyph(b'\x00\x00\x00\x00\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x00\x40\x00\x40\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0', (10, 20), (0, 0), 12),
            71: FontGlyph(b'\xE0\x08\xC0\x00\x83\xE0\x87\xF8\x8F\xF8\x8F\xF8\x8F\xF8\x0F\xF8\x0F\xF8\x0C\x00\x0C\x00\x0F\x80\x0F\x80\x8F\x80\x8F\x80\x8F\x80\x87\x80\x83\x80\xC0\x00\xE0\x00', (13, 20), (0, 0), 15),
            72: FontGlyph(b'\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x00\x00\x00\x00\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80', (12, 20), (0, 0), 14),
            73: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (4, 20), (0, 0), 6),
            74: FontGlyph(b'\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xC0\x02\x06', (7, 20), (0, 0), 9),
            75: FontGlyph(b'\x0F\x00\x0F\x08\x0F\x18\x0E\x18\x0E\x38\x0C\x38\x0C\x78\x08\x78\x08\xF8\x00\xF8\x00\xF8\x08\x78\x08\x78\x0C\x38\x0C\x38\x0E\x18\x0E\x18\x0F\x18\x0F\x08\x0F\x00', (13, 20), (0, 0), 15),
            76: FontGlyph(b'\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x00\x00\x00\x00', (10, 20), (0, 0), 12),
            77: FontGlyph(b'\x03\xF8\x00\x03\xF8\x00\x01\xF0\x00\x01\xF0\x00\x01\xF0\x00\x01\xF0\x00\x01\xF0\x00\x00\xE0\x00\x08\xE2\x00\x08\xE2\x00\x08\xE2\x00\x08\x42\x00\x0C\x46\x00\x0C\x06\x00\x0C\x06\x00\x0C\x06\x00\x0E\x0E\x00\x0E\x0E\x00\x0F\x1E\x00\x0F\x1E\x00', (19, 20), (0, 0), 21),
            78: FontGlyph(b'\x0F\x80\x0F\x80\x07\x80\x07\x80\x03\x80\x03\x80\x01\x80\x01\x80\x01\x80\x00\x80\x08\x80\x08\x00\x08\x00\x0C\x00\x0C\x00\x0E\x00\x0E\x00\x0F\x00\x0F\x00\x0F\x80', (13, 20), (0, 0), 15),
            79: FontGlyph(b'\xE0\x1C\xC0\x0C\x87\x84\x87\x84\x8F\xC4\x8F\xC4\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x8F\xC4\x8F\xC4\x87\x84\x87\x84\xC0\x0C\xE0\x1C', (14, 20), (0, 0), 16),
            80: FontGlyph(b'\x00\x30\x00\x10\x0E\x10\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x10\x0E\x10\x00\x10\x00\x30\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0', (12, 20), (0, 0), 14),
            81: FontGlyph(b'\xE0\x1C\xC0\x0C\x87\x84\x87\x84\x8F\xC4\x8F\xC4\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x08\x40\x88\x44\x8C\x04\x86\x04\x82\x04\xC0\x0C\xE0\x0C\xFF\x84\xFF\x84\xFF\xC0', (14, 23), (0, 0), 16),
            82: FontGlyph(b'\x00\x30\x00\x10\x0E\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0E\x00\x00\x10\x00\x30\x0C\x30\x0C\x30\x0E\x10\x0E\x10\x0E\x10\x0F\x10\x0F\x00\x0F\x00', (12, 20), (0, 0), 14),
            83: FontGlyph(b'\xE0\x10\x80\x10\x87\x90\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x01\xF0\x80\x10\xC0\x10\xFE\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\x3E\x10\x00\x10\x00\x70', (12, 20), (0, 0), 14),
            84: FontGlyph(b'\x00\x00\x00\x00\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8', (13, 20), (0, 0), 14),
            85: FontGlyph(b'\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x07\x00\x80\x08\xC0\x18', (13, 20), (0, 0), 15),
            86: FontGlyph(b'\x0F\xC0\x0F\xC0\x07\xC0\x87\xC4\x87\xC4\xC7\x84\xC7\x84\xC3\x84\xC3\x8C\xC3\x0C\xE3\x0C\xE1\x0C\xE1\x1C\xE1\x1C\xF0\x1C\xF0\x1C\xF0\x3C\xF0\x3C\xF8\x3C\xF8\x7C', (14, 20), (0, 0), 16),
            87: FontGlyph(b'\x0F\x87\x80\x0F\x87\x80\x07\x07\x80\x87\x03\x80\x87\x03\x88\x87\x03\x88\xC7\x03\x08\xC6\x03\x08\xC6\x23\x08\xC2\x21\x18\xC2\x21\x18\xC2\x31\x18\xE2\x31\x18\xE0\x30\x18\xE0\x70\x18\xE0\x70\x38\xE0\x78\x38\xE0\x78\x38\xF0\x78\x38\xF0\x78\x38', (21, 20), (0, 0), 23),
            88: FontGlyph(b'\x07\xE0\x87\xC2\xC3\xC6\xC3\x86\xE1\x8E\xE1\x0E\xF1\x0E\xF0\x1E\xF8\x1E\xF8\x3E\xF8\x3E\xF8\x1E\xF0\x1E\xF1\x0E\xE1\x0E\xE3\x86\xC3\x86\xC3\xC2\x87\xC2\x07\xC0', (15, 20), (0, 0), 17),
            89: FontGlyph(b'\x0F\xC0\x8F\x84\x87\x84\x87\x8C\xC3\x0C\xC3\x0C\xE3\x1C\xE0\x1C\xE0\x3C\xF0\x3C\xF0\x3C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C\xF8\x7C', (14, 20), (0, 0), 16),
            90: FontGlyph(b'\x00\x10\x00\x10\xFE\x10\xFE\x10\xFC\x30\xFC\x30\xF8\x70\xF8\x70\xF0\xF0\xF0\xF0\xE1\xF0\xE1\xF0\xC1\xF0\xC3\xF0\x83\xF0\x87\xF0\x87\xF0\x0F\xF0\x00\x00\x00\x00', (12, 20), (0, 0), 13),
            91: FontGlyph(b'\x00\x00\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x1C\x00\x00', (6, 26), (0, -2), 8),
            92: FontGlyph(b'\x0F\x80\x0F\x80\x8F\x80\x87\x80\xC7\x80\xC7\x80\xC7\x80\xC3\x80\xC3\x80\xE3\x80\xE3\x80\xE1\x80\xE1\x80\xF1\x80\xF1\x80\xF1\x80\xF0\x80\xF8\x80\xF8\x80\xF8\x80\xF8\x00\xFC\x00\xFC\x00', (9, 23), (0, -2), 8),
            93: FontGlyph(b'\x00\x00\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x00\x00', (5, 26), (0, -2), 7),
            94: FontGlyph(b'\xF1\xE0\xE0\xE0\xE0\xE0\xC4\x60\xC4\x60\x8C\x20\x8E\x20\x1E\x00', (11, 8), (0, -2), 11),
            95: FontGlyph(b'\x00\x00\x00\x00', (11, 2), (0, 23), 13),
            96: FontGlyph(b'\x08\x88\xC0\xC0', (5, 4), (0, -1), 7),
            97: FontGlyph(b'\x80\x60\x80\x20\xFC\x20\xFE\x00\xFE\x00\xFE\x00\x80\x00\x00\x00\x0E\x00\x1E\x00\x1E\x00\x1E\x00\x0C\x00\x00\x00\x80\x00', (11, 15), (0, 5), 13),
            98: FontGlyph(b'\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x00\x60\x00\x20\x0C\x20\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x0C\x20\x00\x20\x00\x60', (11, 22), (0, -2), 13),
            99: FontGlyph(b'\xC0\x00\x80\x00\x87\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x0F\x80\x87\x80\x80\x00\xC0\x00', (9, 15), (0, 5), 11),
            100: FontGlyph(b'\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xC1\x00\x80\x00\x86\x00\x0E\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0E\x00\x86\x00\x80\x00\xC0\x00', (11, 22), (0, -2), 13),
            101: FontGlyph(b'\xC0\x60\x80\x20\x86\x00\x0E\x00\x0F\x00\x0F\x00\x00\x00\x00\x00\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x87\xE0\x80\x00\xC0\x00', (11, 15), (0, 5), 13),
            102: FontGlyph(b'\xE0\xC0\xC3\xC7\xC7\xC7\xC7\x00\x00\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7', (8, 22), (0, -2), 9),
            103: FontGlyph(b'\xC0\x00\x80\x00\x86\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x86\x00\x80\x00\xC0\x00\xFF\x00\xFF\x00\xFE\x00\xFC\x00\x80\x20\x80\x60', (11, 21), (0, 5), 13),
            104: FontGlyph(b'\x1F\xC0\x1F\xC0\x1F\xC0\x1F\xC0\x1F\xC0\x1F\xC0\x1F\xC0\x10\x40\x00\x00\x0C\x00\x0E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00', (10, 22), (0, -2), 12),
            105: FontGlyph(b'\x00\x00\xE0\xE0\xE0\xE0\xE0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (3, 22), (0, -2), 5),
            106: FontGlyph(b'\xC0\xC0\xF8\xF8\xF8\xF8\xF8\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x80\x00\x08', (5, 28), (-1, -2), 6),
            107: FontGlyph(b'\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1E\x20\x1C\x20\x1C\x60\x18\x60\x18\xE0\x10\xE0\x11\xE0\x01\xE0\x01\xE0\x10\xE0\x10\xE0\x18\x60\x18\x60\x1C\x20\x1C\x00', (11, 22), (0, -2), 12),
            108: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (3, 22), (0, -2), 5),
            109: FontGlyph(b'\x10\x40\x80\x00\x00\x00\x0C\x18\x00\x0C\x18\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00\x1E\x3C\x00', (17, 15), (0, 5), 19),
            110: FontGlyph(b'\x10\x40\x00\x00\x0C\x00\x0E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00', (10, 15), (0, 5), 12),
            111: FontGlyph(b'\xC0\x60\x80\x20\x86\x20\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x86\x20\x80\x20\xC0\x60', (11, 15), (0, 5), 13),
            112: FontGlyph(b'\x00\x60\x00\x20\x0C\x20\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x0C\x20\x00\x20\x00\x60\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0\x1F\xE0', (11, 21), (0, 5), 13),
            113: FontGlyph(b'\xC0\x00\x80\x00\x86\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x0F\x00\x86\x00\x80\x00\xC0\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00', (11, 21), (0, 5), 13),
            114: FontGlyph(b'\x10\x00\x06\x0E\x0E\x1E\x1E\x1E\x1E\x1E\x1E\x1E\x1E\x1E\x1E', (7, 15), (0, 5), 8),
            115: FontGlyph(b'\xC0\x40\x80\x40\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x01\xC0\x80\x40\xF0\x00\xFC\x00\xFC\x00\xFC\x00\xFC\x00\x00\x40\x00\xC0', (10, 15), (0, 5), 12),
            116: FontGlyph(b'\xC7\xC7\xC7\xC7\x00\x00\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7\xC7', (8, 19), (0, 1), 10),
            117: FontGlyph(b'\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x0C\x00\x00\x00\x80\x00', (10, 15), (0, 5), 12),
            118: FontGlyph(b'\x0F\x80\x0F\x00\x87\x00\x87\x10\xC7\x10\xC7\x10\xC2\x10\xC2\x30\xE2\x30\xE2\x30\xE0\x30\xE0\x70\xF0\x70\xF0\x70\xF0\x70', (12, 15), (0, 5), 14),
            119: FontGlyph(b'\x1E\x3C\x00\x1C\x1C\x00\x0C\x18\x00\x0C\x18\x00\x0C\x18\x80\x8C\x18\x80\x88\x08\x80\x80\x88\x80\x80\x80\x80\xC0\x81\x80\xC0\x81\x80\xC0\x81\x80\xC1\xC1\x80\xC1\xC1\x80\xE1\xC3\x80', (17, 15), (0, 5), 19),
            120: FontGlyph(b'\x87\x88\x87\x08\xC3\x18\xC2\x18\xE0\x38\xE0\x38\xF0\x78\xF0\x78\xF0\x78\xE0\x38\xE2\x38\xC2\x18\xC7\x18\x87\x08\x0F\x80', (13, 15), (0, 5), 15),
            121: FontGlyph(b'\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1C\x00\x0C\x00\x00\x00\x82\x00\xFE\x00\xFE\x00\xFC\x00\xFC\x00\x00\x40\x00\xC0', (10, 21), (0, 5), 12),
            122: FontGlyph(b'\x00\x00\x00\x00\xFC\x00\xF8\x40\xF8\x40\xF0\xC0\xF0\xC0\xE1\xC0\xC3\xC0\xC3\xC0\x87\xC0\x87\xC0\x0F\xC0\x00\x00\x00\x00', (10, 15), (0, 5), 12),
            123: FontGlyph(b'\xF0\xE2\xC2\xC6\xC6\xC6\xC6\xC6\xC6\xC6\xC6\x8E\x1E\x8E\x86\xC6\xC6\xC6\xC6\xC6\xC6\xC6\xC6\xC2\xE2\xF0', (7, 26), (0, -2), 9),
            124: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (4, 26), (0, -2), 6),
            125: FontGlyph(b'\x0F\xC7\xC3\xC3\xE3\xE3\xE3\xE3\xE3\xE3\xE3\xF1\xF8\xF1\xE3\xE3\xE3\xE3\xE3\xE3\xE3\xE3\xC3\xC7\xC7\x0F', (8, 26), (0, -2), 10),
            126: FontGlyph(b'\x81\x81\x18\x18\x18\x18\x18\x18\x18\x81\x81', (8, 11), (0, 0), 10)
        }

    class SairaCondensed30:
        glyphs = {
            32: FontGlyph(b'\x80', (1, 1), (3, 0), 9),
            33: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x84\x84\x84\x84\x84\x84\x84\x84\x84\x84\x84\xFC\xFC\xFC\xFC\x80\x80\x80\x80', (6, 28), (0, 0), 8),
            34: FontGlyph(b'\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00\x0C\x00', (10, 10), (0, 0), 12),
            35: FontGlyph(b'\xF8\x70\xC0\xF8\x70\xC0\xF8\x70\xC0\xF8\x70\xC0\xF8\xF1\xC0\xF8\xF1\xC0\xF0\xE1\xC0\xF0\xE1\xC0\x80\x00\x00\x80\x00\x00\x80\x00\x00\xF1\xE1\xC0\xE1\xC3\xC0\xE1\xC3\xC0\xE1\xC3\xC0\xE1\xC3\xC0\xE1\xC3\xC0\x00\x00\x40\x00\x00\x40\x00\x00\x40\xC3\x87\xC0\xC3\x87\xC0\xC3\x87\xC0\xC3\x87\xC0\xC7\x8F\xC0\x87\x0F\xC0\x87\x0F\xC0\x87\x0F\xC0', (18, 28), (0, 0), 20),
            36: FontGlyph(b'\xF8\x7C\xF8\x7C\xF8\x7C\xE0\x0C\x80\x04\x80\x04\x07\xE4\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x00\x3C\x80\x0C\xC0\x04\xFC\x04\xFF\x80\xFF\x80\xFF\x80\xFF\x80\xFF\x80\xFF\x04\x00\x04\x00\x0C\x00\x1C\xF8\x7C\xF8\x7C\xF8\x7C', (14, 28), (0, 0), 16),
            37: FontGlyph(b'\xC0\xFF\x8E\x80\x7F\x1E\x0C\x3F\x1E\x0C\x3E\x1E\x1E\x3E\x3E\x1E\x3C\x3E\x1E\x3C\x7E\x1E\x38\x7E\x1E\x38\xFE\x1E\x30\xFE\x1E\x31\xFE\x0C\x21\xFE\x0C\x22\x02\x80\x40\x00\xC0\xC4\x20\xFF\x84\x70\xFF\x8C\x70\xFF\x0C\x70\xFF\x1C\x70\xFE\x1C\x70\xFE\x3C\x70\xFC\x3C\x70\xFC\x7C\x70\xF8\x7C\x70\xF8\xFC\x70\xF0\xFC\x20\xF1\xFC\x00\xE1\xFE\x02', (23, 28), (0, 0), 25),
            38: FontGlyph(b'\xF0\x01\xF0\xC0\x00\xF0\x80\x00\xF0\x81\xFC\xF0\x07\xFF\xF0\x07\xFF\xF0\x07\xFF\xF0\x07\xFF\xF0\x07\xFF\xF0\x07\xFF\xF0\x87\xFF\xF0\x83\xFF\xF0\xC0\x30\x00\xF0\x30\x00\xC0\x30\x00\x83\xF0\xF0\x07\xF0\xF0\x07\xF0\xF0\x07\xF0\xF0\x0F\xF0\xF0\x0F\xF0\xF0\x07\xF0\xF0\x07\xF0\xF0\x07\xF0\xF0\x03\xF0\xF0\x80\x00\xF0\xC0\x00\xF0\xF0\x01\xF0', (20, 28), (0, 0), 22),
            39: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (4, 10), (0, 0), 6),
            40: FontGlyph(b'\xF8\x00\xF0\x80\xE1\x80\xE1\x80\xC3\x80\xC3\x80\x83\x80\x83\x80\x87\x80\x87\x80\x87\x80\x87\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x07\x80\x87\x80\x87\x80\x87\x80\x87\x80\x83\x80\x83\x80\xC3\x80\xC3\x80\xE1\x80\xE1\x80\xF0\x80\xF8\x00', (9, 36), (0, -2), 11),
            41: FontGlyph(b'\x0F\x0F\x87\xC3\xC3\xC3\xE1\xE1\xE1\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE1\xE1\xE1\xE1\xC3\xC3\xC7\x87\x0F\x0F', (8, 36), (-1, -2), 9),
            42: FontGlyph(b'\xF8\xF8\xF8\xF8\x98\xC8\x08\x80\x00\x00\xC0\x18\xF0\x78\xC0\x18\x00\x00\x08\x80\x98\xC8\xF8\xF8\xF8\xF8', (13, 13), (0, 0), 15),
            43: FontGlyph(b'\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F\x00\x00\x00\x00\x00\x00\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F\xFC\x3F', (16, 15), (0, 10), 18),
            44: FontGlyph(b'\x00\x00\x00\x00\xC0\xC0\x80\x00\x08', (5, 9), (0, 24), 7),
            45: FontGlyph(b'\x00\x00\x00\x00\x00\x00', (9, 3), (0, 15), 11),
            46: FontGlyph(b'\x00\x00\x00\x00', (5, 4), (0, 24), 7),
            47: FontGlyph(b'\xFE\x00\xFE\x00\xFE\x00\xFC\x00\xFC\x20\xFC\x20\xFC\x20\xF8\x20\xF8\x60\xF8\x60\xF8\x60\xF8\x60\xF0\xE0\xF0\xE0\xF0\xE0\xF0\xE0\xE0\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xC1\xE0\xC3\xE0\xC3\xE0\xC3\xE0\x83\xE0\x87\xE0\x87\xE0\x87\xE0\x87\xE0\x0F\xE0\x0F\xE0\x0F\xE0', (11, 32), (-1, -2), 12),
            48: FontGlyph(b'\xF0\x0F\xC0\x03\x80\x01\x83\xC1\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x83\xC1\x80\x01\xC0\x03\xF0\x0F', (16, 28), (0, 0), 18),
            49: FontGlyph(b'\xF0\x00\xC0\x00\x80\x00\x00\x00\x00\x00\x10\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00\xF0\x00', (9, 28), (0, 0), 11),
            50: FontGlyph(b'\x80\x0E\x00\x06\x00\x02\x3F\x82\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\x82\xFE\x02\xF8\x06\xF0\x0E\xC0\x3E\x80\x7E\x01\xFE\x07\xFE\x07\xFE\x07\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x00\x00\x00\x00\x00\x00', (15, 28), (0, 0), 17),
            51: FontGlyph(b'\x80\x1E\x00\x06\x00\x02\x3F\x82\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC2\xFF\x82\xE0\x06\xE0\x1E\xE0\x06\xFF\x82\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\x80\x00\x02\x00\x06\x00\x1E', (15, 28), (0, 0), 17),
            52: FontGlyph(b'\xFE\x0F\xC0\xFC\x0F\xC0\xFC\x1F\xC0\xFC\x1F\xC0\xF8\x3F\xC0\xF8\x3F\xC0\xF8\x3F\xC0\xF0\x7F\xC0\xF0\x7F\xC0\xF0\xE1\xC0\xE0\xE1\xC0\xE0\xE1\xC0\xE1\xE1\xC0\xC1\xE1\xC0\xC1\xC1\xC0\xC3\xC1\xC0\x83\xC1\xC0\x83\xC1\xC0\x07\xC1\xC0\x00\x00\x00\x00\x00\x00\x00\x00\x00\xFF\xC1\xC0\xFF\xC1\xC0\xFF\xC1\xC0\xFF\xC1\xC0\xFF\xC1\xC0\xFF\xC1\xC0', (18, 28), (0, 0), 20),
            53: FontGlyph(b'\x00\x02\x00\x02\x00\x02\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x00\x0E\x00\x06\x00\x02\x3F\x80\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\x82\x00\x02\x00\x06\x00\x1E', (15, 28), (0, 0), 17),
            54: FontGlyph(b'\xF8\x03\xE0\x01\xC0\x00\x81\xFC\x83\xFF\x87\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x04\x03\x00\x01\x00\x00\x03\xE0\x07\xE0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x87\xE0\x83\xE0\x80\x01\xC0\x01\xF0\x07', (16, 28), (0, 0), 18),
            55: FontGlyph(b'\x00\x00\x00\x00\x00\x00\xFF\xC0\xFF\xC0\xFF\x82\xFF\x82\xFF\x82\xFF\x06\xFF\x06\xFF\x06\xFF\x0E\xFE\x0E\xFE\x0E\xFE\x0E\xFC\x1E\xFC\x1E\xFC\x1E\xF8\x3E\xF8\x3E\xF8\x3E\xF0\x7E\xF0\x7E\xF0\x7E\xE0\xFE\xE0\xFE\xC0\xFE\xC1\xFE', (15, 28), (0, 0), 17),
            56: FontGlyph(b'\xF0\x07\x80\xC0\x01\x80\x80\x00\x80\x03\xE0\x80\x07\xE0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xE0\x80\x83\xE0\x80\xC0\x01\x80\xE0\x07\x80\x80\x01\x80\x83\xE0\x80\x07\xF0\x80\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xE0\x80\x03\xE0\x80\x80\x00\x80\xC0\x01\x80\xF0\x07\x80', (17, 28), (0, 0), 19),
            57: FontGlyph(b'\xE0\x0F\xC0\x03\x80\x01\x03\xC1\x07\xE1\x07\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x07\xE0\x07\xE0\x07\xC0\x00\x00\x80\x00\xE0\x20\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xC1\x9F\x81\x80\x03\x80\x07\x80\x1F', (16, 28), (0, 0), 18),
            58: FontGlyph(b'\x00\x00\x00\x00\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\x00\x00\x00\x00', (5, 21), (0, 7), 7),
            59: FontGlyph(b'\x00\x00\x00\x00\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\xF8\x00\x00\x00\x00\xC0\xC0\x80\x00\x08', (5, 26), (0, 7), 7),
            60: FontGlyph(b'\xFF\xFC\xFF\xF0\xFF\x80\xFE\x01\xF0\x07\xC0\x3F\x00\xFF\x07\xFF\x01\xFF\x80\x7F\xE0\x0F\xFC\x03\xFF\x00\xFF\xC0\xFF\xF8', (16, 15), (0, 10), 18),
            61: FontGlyph(b'\x00\x00\x00\x00\x00\x00\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF\x00\x00\x00\x00\x00\x00', (16, 10), (0, 13), 18),
            62: FontGlyph(b'\x3F\xFF\x07\xFF\x01\xFF\x80\x7F\xE0\x0F\xFC\x03\xFF\x00\xFF\xE0\xFF\xC0\xFE\x00\xF8\x07\xC0\x1F\x00\xFF\x03\xFF\x1F\xFF', (16, 15), (0, 10), 18),
            63: FontGlyph(b'\x00\x38\x00\x18\x00\x08\x3E\x08\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFF\x00\xFE\x00\xFC\x08\xF0\x08\xE0\x38\xE0\x78\xE0\xF8\xE1\xF8\xE1\xF8\xE1\xF8\xE1\xF8\xFF\xF8\xFF\xF8\xFF\xF8\xFF\xF8\xE0\xF8\xE0\xF8\xE0\xF8\xE0\xF8', (13, 28), (0, 0), 15),
            64: FontGlyph(b'\xFC\x00\x1F\xE0\x00\x07\xC3\xFF\xC3\xC7\xFF\xF1\x8F\xFF\xF1\x8F\xFF\xF8\x8F\xFF\xF8\x8E\x00\xF8\x8E\x00\x78\x9E\x00\x38\x1F\xF8\x38\x1F\xFC\x38\x1F\xFC\x38\x1F\xFC\x38\x1F\xFC\x38\x1F\x00\x38\x1E\x00\x38\x1C\x1C\x38\x1C\x3C\x38\x1C\x3C\x38\x1C\x3C\x38\x1C\x3C\x38\x1C\x18\x38\x9C\x00\x01\x8E\x00\x01\x8F\x07\xFF\x8F\xFF\xFF\x8F\xFF\xFF\x8F\xFF\xFF\xC7\xFF\xFF\xC3\xFF\xFF\xE0\x00\x3F\xFC\x00\x3F', (24, 33), (0, 0), 26),
            65: FontGlyph(b'\xFC\x07\xE0\xFC\x07\xE0\xFC\x07\xE0\xF8\x07\xE0\xF8\x03\xE0\xF8\x03\xE0\xF8\x03\xE0\xF8\x43\xE0\xF0\x41\xE0\xF0\x41\xE0\xF0\xC1\xE0\xF0\xC1\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE1\xE0\xE0\xC1\xF0\xE0\xC1\xF0\x60\xC0\x00\x60\xC0\x00\x60\x80\x00\x60\x83\xF8\x20\x83\xF8\x20\x87\xF8\x20\x07\xFC\x20\x07\xFC\x00\x07\xFC\x00\x0F\xFC\x00', (19, 28), (0, 0), 21),
            66: FontGlyph(b'\x00\x0F\x00\x03\x00\x01\x0F\xC1\x0F\xC1\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE1\x0F\xC1\x0F\x81\x00\x03\x00\x0F\x00\x03\x0F\xC1\x0F\xC1\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xC1\x00\x01\x00\x03\x00\x0F', (16, 28), (0, 0), 18),
            67: FontGlyph(b'\xF0\x04\xC0\x00\xC0\x00\x81\xFC\x83\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x83\xFC\x81\xFC\xC0\x00\xC0\x00\xF0\x00', (14, 28), (0, 0), 16),
            68: FontGlyph(b'\x00\x0F\x00\x03\x00\x01\x0F\x81\x0F\xC1\x0F\xE1\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE1\x0F\xC1\x0F\x81\x00\x01\x00\x03\x00\x0F', (16, 28), (0, 0), 18),
            69: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x00\x0C\x00\x0C\x00\x0C\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x00\x00\x00\x00\x00\x00', (14, 28), (0, 0), 16),
            70: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x00\x08\x00\x08\x00\x08\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8', (13, 28), (0, 0), 15),
            71: FontGlyph(b'\xF8\x01\xE0\x00\xC0\x00\x81\xFC\x83\xFF\x87\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x07\x00\x07\x00\x07\x00\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x07\xF0\x87\xF0\x83\xF0\x81\xF0\xC0\x00\xE0\x00\xF0\x01', (16, 28), (0, 0), 18),
            72: FontGlyph(b'\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x00\x00\x00\x00\x00\x00\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0', (16, 28), (0, 0), 18),
            73: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (4, 28), (0, 0), 6),
            74: FontGlyph(b'\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xE0\xC0\x00\x01\x03', (8, 28), (-1, 0), 9),
            75: FontGlyph(b'\x0F\xF0\x00\x0F\xE0\x80\x0F\xE0\x80\x0F\xC1\x80\x0F\xC3\x80\x0F\x83\x80\x0F\x87\x80\x0F\x07\x80\x0F\x0F\x80\x0E\x0F\x80\x0E\x1F\x80\x0C\x1F\x80\x00\x3F\x80\x00\x3F\x80\x00\x1F\x80\x0C\x1F\x80\x0E\x0F\x80\x0E\x0F\x80\x0E\x0F\x80\x0F\x07\x80\x0F\x07\x80\x0F\x83\x80\x0F\x83\x80\x0F\xC1\x80\x0F\xC1\x80\x0F\xE0\x80\x0F\xE0\x80\x0F\xE0\x00', (17, 28), (0, 0), 19),
            76: FontGlyph(b'\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x0F\xF8\x00\x00\x00\x00\x00\x00', (13, 28), (0, 0), 15),
            77: FontGlyph(b'\x03\xFF\x00\x03\xFE\x00\x01\xFE\x00\x01\xFE\x00\x01\xFE\x00\x01\xFE\x00\x00\xFC\x00\x00\xFC\x00\x00\xFC\x00\x00\xFC\x00\x00\x78\x40\x08\x78\x40\x08\x78\x40\x08\x78\x40\x08\x30\xC0\x0C\x30\xC0\x0C\x30\xC0\x0C\x30\xC0\x0C\x01\xC0\x0E\x01\xC0\x0E\x01\xC0\x0E\x01\xC0\x0E\x03\xC0\x0F\x03\xC0\x0F\x03\xC0\x0F\x03\xC0\x0F\x07\xC0\x0F\x87\xC0', (22, 28), (0, 0), 24),
            78: FontGlyph(b'\x07\xF0\x07\xF0\x03\xF0\x03\xF0\x03\xF0\x01\xF0\x01\xF0\x00\xF0\x00\xF0\x00\x70\x00\x70\x08\x70\x08\x30\x0C\x30\x0C\x10\x0C\x10\x0E\x10\x0E\x00\x0F\x00\x0F\x00\x0F\x80\x0F\x80\x0F\x80\x0F\xC0\x0F\xC0\x0F\xE0\x0F\xE0\x0F\xF0', (16, 28), (0, 0), 18),
            79: FontGlyph(b'\xF0\x03\xC0\xC0\x01\xC0\x80\x00\xC0\x83\xE0\x40\x87\xF0\x40\x07\xF0\x40\x07\xF8\x40\x07\xF8\x40\x07\xF8\x40\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x40\x07\xF8\x40\x07\xF8\x40\x07\xF0\x40\x87\xF0\x40\x83\xE0\x40\x80\x00\xC0\xC0\x01\xC0\xF0\x03\xC0', (18, 28), (0, 0), 20),
            80: FontGlyph(b'\x00\x0E\x00\x02\x00\x02\x0F\x80\x0F\xC0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xC0\x0F\x80\x00\x02\x00\x02\x00\x0E\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE\x0F\xFE', (15, 28), (0, 0), 17),
            81: FontGlyph(b'\xF0\x03\xC0\xC0\x01\xC0\x80\x00\xC0\x83\xE0\x40\x87\xF0\x40\x07\xF0\x40\x07\xF8\x40\x07\xF8\x40\x07\xF8\x40\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x00\x04\x18\x40\x06\x08\x40\x06\x08\x40\x07\x00\x40\x87\x80\x40\x83\x80\x40\x80\x00\xC0\xC0\x00\xC0\xF0\x00\xC0\xFF\xE0\xC0\xFF\xF0\x40\xFF\xF8\x00\xFF\xF8\x00', (18, 32), (0, 0), 20),
            82: FontGlyph(b'\x00\x07\x00\x03\x00\x01\x0F\xC1\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE0\x0F\xE1\x0F\xC1\x00\x01\x00\x03\x00\x07\x0F\x07\x0F\x87\x0F\x83\x0F\x83\x0F\x83\x0F\xC1\x0F\xC1\x0F\xC1\x0F\xE0\x0F\xE0\x0F\xE0', (16, 28), (0, 0), 18),
            83: FontGlyph(b'\xF0\x01\xE0\x01\xC0\x01\x81\xFF\x83\xFF\x87\xFF\x07\xFF\x07\xFF\x07\xFF\x07\xFF\x83\xFF\x80\xFF\x80\x07\x80\x01\xC0\x01\xFE\x00\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xE0\xFF\xC0\x80\x01\x80\x03\x80\x07', (16, 28), (0, 0), 18),
            84: FontGlyph(b'\x00\x00\x00\x00\x00\x00\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F\xF8\x3F', (16, 28), (0, 0), 18),
            85: FontGlyph(b'\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x00\x87\xF0\x00\x87\xF0\x00\x83\xF0\x00\x81\xE0\x80\xC0\x00\x80\xC0\x01\x80\xF0\x07\x80', (17, 28), (0, 0), 19),
            86: FontGlyph(b'\x0F\xF8\x00\x07\xF8\x00\x07\xF8\x00\x07\xF8\x40\x07\xF8\x40\x87\xF0\x40\x83\xF0\x40\x83\xF0\x40\x83\xF0\xC0\xC3\xE0\xC0\xC3\xE0\xC0\xC1\xE0\xC0\xC1\xE1\xC0\xC1\xE1\xC0\xE1\xC1\xC0\xE0\xC1\xC0\xE0\xC1\xC0\xE0\xC3\xC0\xF0\xC3\xC0\xF0\x83\xC0\xF0\x03\xC0\xF0\x07\xC0\xF8\x07\xC0\xF8\x07\xC0\xF8\x07\xC0\xF8\x0F\xC0\xF8\x0F\xC0\xFC\x0F\xC0', (18, 28), (0, 0), 20),
            87: FontGlyph(b'\x0F\xE0\xFE\x00\x07\xE0\x7E\x00\x07\xE0\x7E\x10\x07\xC0\x7C\x10\x07\xC0\x7C\x10\x87\xC0\x7C\x10\x87\xC0\x3C\x10\x83\xC0\x3C\x10\x83\xC0\x3C\x30\x83\x80\x3C\x30\x83\x84\x38\x30\xC3\x84\x38\x30\xC3\x84\x18\x30\xC3\x86\x18\x70\xC1\x86\x18\x70\xC1\x0E\x18\x70\xC1\x0E\x18\x70\xE1\x0E\x10\x70\xE1\x0E\x00\x70\xE1\x0F\x00\xF0\xE1\x0F\x00\xF0\xE0\x1F\x00\xF0\xE0\x1F\x00\xF0\xF0\x1F\x00\xF0\xF0\x1F\x80\xF0\xF0\x1F\x81\xF0\xF0\x1F\x81\xF0\xF0\x3F\x81\xF0', (28, 28), (0, 0), 30),
            88: FontGlyph(b'\x07\xFC\x00\x03\xF8\x00\x83\xF8\x00\x83\xF0\x40\xC1\xF0\x40\xC1\xE0\xC0\xE0\xE0\xC0\xE0\xC1\xC0\xF0\x41\xC0\xF0\x43\xC0\xF8\x03\xC0\xF8\x07\xC0\xFC\x07\xC0\xFC\x0F\xC0\xFC\x07\xC0\xFC\x07\xC0\xF8\x03\xC0\xF8\x03\xC0\xF0\x03\xC0\xF0\xC1\xC0\xE0\xC1\xC0\xE0\xE0\xC0\xC1\xE0\xC0\xC1\xF0\x40\x83\xF0\x40\x83\xF8\x00\x07\xF8\x00\x07\xFC\x00', (18, 28), (0, 0), 20),
            89: FontGlyph(b'\x0F\xF8\x00\x07\xF0\x00\x07\xF0\x00\x07\xF0\x80\x83\xE0\x80\x83\xE1\x80\xC3\xC1\x80\xC1\xC1\x80\xC1\xC3\x80\xE1\x83\x80\xE0\x83\x80\xF0\x87\x80\xF0\x07\x80\xF0\x0F\x80\xF8\x0F\x80\xF8\x0F\x80\xF8\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80\xFC\x1F\x80', (17, 28), (0, 0), 19),
            90: FontGlyph(b'\x00\x00\x00\x00\x00\x00\xFF\xC0\xFF\xC1\xFF\x81\xFF\x83\xFF\x03\xFF\x07\xFE\x07\xFE\x0F\xFE\x0F\xFC\x1F\xFC\x1F\xF8\x3F\xF8\x3F\xF0\x7F\xF0\x7F\xE0\x7F\xE0\xFF\xC0\xFF\xC1\xFF\x81\xFF\x83\xFF\x03\xFF\x00\x00\x00\x00\x00\x00', (16, 28), (0, 0), 18),
            91: FontGlyph(b'\x00\x00\x00\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x0E\x00\x00\x00', (7, 37), (0, -2), 9),
            92: FontGlyph(b'\x0F\xE0\x0F\xE0\x0F\xE0\x07\xE0\x87\xE0\x87\xE0\x87\xE0\x83\xE0\xC3\xE0\xC3\xE0\xC3\xE0\xC1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE0\xE0\xF0\xE0\xF0\xE0\xF0\xE0\xF0\x60\xF8\x60\xF8\x60\xF8\x60\xF8\x20\xFC\x20\xFC\x20\xFC\x20\xFC\x20\xFE\x00\xFE\x00\xFE\x00', (11, 32), (0, -2), 13),
            93: FontGlyph(b'\x00\x00\x00\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\xF0\x00\x00\x00', (8, 37), (0, -2), 10),
            94: FontGlyph(b'\xF8\x3E\xF8\x3E\xF0\x1E\xF0\x1E\xE1\x0E\xE1\x0E\xE3\x86\xC3\x86\xC3\xC2\x87\xC2\x07\xC0', (15, 11), (0, -2), 17),
            95: FontGlyph(b'\x00\x00\x00\x00\x00\x00', (14, 3), (0, 32), 16),
            96: FontGlyph(b'\x06\x86\xC2\xC2\xE0\xE0', (7, 6), (0, -2), 9),
            97: FontGlyph(b'\xC0\x0E\x80\x06\x80\x02\xFF\x82\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xC0\x00\x80\x00\x80\x00\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\x80\x80\x00\x80\x00\xE0\x40', (15, 21), (0, 7), 17),
            98: FontGlyph(b'\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x04\x0E\x00\x02\x00\x02\x03\x80\x07\xC0\x07\xC0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xC0\x07\xC0\x03\x80\x00\x02\x00\x02\x04\x0E', (15, 30), (0, -2), 17),
            99: FontGlyph(b'\xE0\x10\x80\x00\x80\x00\x03\xC0\x07\xF0\x07\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x0F\xF0\x07\xF0\x07\xF0\x03\xF0\x80\x00\x80\x00\xE0\x00', (12, 21), (0, 7), 14),
            100: FontGlyph(b'\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xE0\x40\x80\x00\x80\x00\x07\x80\x07\x80\x07\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x07\xC0\x07\x80\x07\x80\x80\x00\x80\x00\xE0\x40', (15, 30), (0, -2), 17),
            101: FontGlyph(b'\xE0\x1C\x80\x04\x80\x00\x07\x80\x07\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x00\x00\x00\x00\x00\x00\x0F\xFC\x0F\xFC\x0F\xFC\x0F\xFC\x07\xFC\x03\xFC\x80\x00\x80\x00\xE0\x04', (14, 21), (0, 7), 16),
            102: FontGlyph(b'\xF8\x00\xF0\x00\xE0\x00\xE0\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\x00\x00\x00\x00\x00\x00\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0', (11, 30), (0, -2), 13),
            103: FontGlyph(b'\xE0\x40\x80\x00\x80\x00\x07\x80\x07\x80\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x07\x80\x07\x80\x80\x00\x80\x00\xE0\x40\xFF\xC2\xFF\xC2\xFF\xC2\xFF\x82\xFF\x02\x80\x06\x80\x06\x80\x1E', (15, 29), (0, 7), 17),
            104: FontGlyph(b'\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x04\x0E\x00\x02\x00\x02\x03\x80\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0', (15, 30), (0, -2), 17),
            105: FontGlyph(b'\x00\x00\x00\x00\xF8\xF8\xF8\xF8\xF8\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (5, 30), (0, -2), 7),
            106: FontGlyph(b'\xC0\xC0\xC0\xC0\xFE\xFE\xFE\xFE\xFE\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\xC0\x02\x02\x06', (7, 38), (-2, -2), 7),
            107: FontGlyph(b'\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xC0\x07\x82\x07\x82\x07\x06\x07\x06\x06\x0E\x06\x0E\x04\x1E\x04\x3E\x00\x3E\x00\x3E\x00\x3E\x04\x1E\x04\x1E\x06\x0E\x06\x0E\x07\x06\x07\x06\x07\x82\x07\x82\x07\xC0', (15, 30), (0, -2), 17),
            108: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (5, 30), (0, -2), 7),
            109: FontGlyph(b'\x04\x0E\x03\x00\x00\x01\x00\x00\x01\x03\x80\xE0\x07\xC1\xE0\x07\xC1\xE0\x07\xC1\xE0\x07\xC1\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0\x07\xC3\xF0', (24, 21), (0, 7), 26),
            110: FontGlyph(b'\x04\x0E\x00\x02\x00\x02\x03\x80\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0', (15, 21), (0, 7), 17),
            111: FontGlyph(b'\xE0\x0E\x80\x06\x80\x02\x07\x82\x07\xC2\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x07\xC2\x07\x82\x80\x02\x80\x06\xE0\x0E', (15, 21), (0, 7), 17),
            112: FontGlyph(b'\x04\x0E\x00\x02\x00\x02\x03\x80\x07\xC0\x07\xC0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xE0\x07\xC0\x07\xC0\x03\x80\x00\x02\x00\x02\x04\x0E\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE\x07\xFE', (15, 29), (0, 7), 17),
            113: FontGlyph(b'\xE0\x40\x80\x00\x80\x00\x07\x80\x07\x80\x07\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x0F\xC0\x07\xC0\x07\x80\x07\x80\x80\x00\x80\x00\xE0\x40\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0\xFF\xC0', (15, 29), (0, 7), 17),
            114: FontGlyph(b'\x04\x00\x00\x00\x00\x00\x00\xC0\x03\xC0\x03\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0', (10, 21), (0, 7), 12),
            115: FontGlyph(b'\xE0\x04\xC0\x04\x80\x04\x83\xE4\x07\xFC\x07\xFC\x07\xFC\x07\xFC\x83\xFC\x80\x1C\x80\x04\xF0\x04\xFF\x80\xFF\x80\xFF\x80\xFF\x80\xFF\x80\xFF\x04\x80\x04\x80\x0C\x80\x1C', (14, 21), (0, 7), 16),
            116: FontGlyph(b'\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\x00\x00\x00\x00\x00\x00\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0\xE1\xE0', (11, 27), (0, 1), 13),
            117: FontGlyph(b'\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x83\x80\x80\x00\x80\x00\xE0\x40', (15, 21), (0, 7), 17),
            118: FontGlyph(b'\x0F\xE0\x07\xE1\x07\xE1\x87\xC1\x87\xC1\x83\xC3\x83\xC3\xC3\x83\xC3\x83\xC3\x87\xC1\x87\xE1\x87\xE1\x07\xE1\x0F\xE0\x0F\xF0\x0F\xF0\x0F\xF0\x1F\xF0\x1F\xF8\x1F\xF8\x1F', (16, 21), (0, 7), 18),
            119: FontGlyph(b'\x0F\xC3\xF0\x07\x81\xE0\x07\x81\xE0\x07\x81\xE1\x87\x81\xE1\x87\x81\xE1\x83\x00\xC1\x83\x00\xC1\x83\x00\xC3\xC3\x00\xC3\xC3\x10\xC3\xC2\x18\xC3\xC0\x18\x07\xE0\x18\x07\xE0\x18\x07\xE0\x18\x07\xE0\x3C\x07\xE0\x3C\x0F\xF0\x3C\x0F\xF0\x3C\x0F\xF0\x3C\x0F', (24, 21), (0, 7), 26),
            120: FontGlyph(b'\x07\xE0\x87\xC1\x83\xC1\xC3\x83\xC1\x83\xE1\x07\xE0\x0F\xF0\x0F\xF0\x1F\xF8\x1F\xF8\x1F\xF0\x1F\xF0\x0F\xE0\x0F\xE1\x07\xC1\x07\xC1\x83\x83\x83\x83\xC1\x07\xC1\x07\xE0', (16, 21), (0, 7), 18),
            121: FontGlyph(b'\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x07\xC0\x83\x80\x80\x00\x80\x00\xE0\x40\xFF\xC0\xFF\xC0\xFF\xC2\xFF\xC2\xFF\x02\x80\x06\x80\x06\x80\x1E', (15, 29), (0, 7), 17),
            122: FontGlyph(b'\x80\x00\x80\x00\x80\x00\xFF\x04\xFF\x04\xFE\x0C\xFE\x0C\xFC\x1C\xFC\x1C\xF8\x3C\xF0\x3C\xF0\x7C\xE0\x7C\xE0\xFC\xC1\xFC\xC1\xFC\x83\xFC\x83\xFC\x00\x00\x00\x00\x00\x00', (14, 21), (0, 7), 16),
            123: FontGlyph(b'\xFC\x00\xF8\x40\xF0\xC0\xF0\xC0\xE0\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xC1\xC0\x83\xC0\x07\xC0\x07\xC0\x83\xC0\xC1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE0\xC0\xF0\xC0\xF0\xC0\xF8\x40\xFC\x00', (10, 36), (0, -2), 12),
            124: FontGlyph(b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00', (4, 36), (0, -2), 6),
            125: FontGlyph(b'\x0F\xC0\x87\xC0\x83\xC0\xC3\xC0\xC1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE0\xC0\xF0\xC0\xF8\x00\xF8\x00\xF0\x40\xE0\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xE1\xC0\xC1\xC0\xC3\xC0\x83\xC0\x87\xC0\x0F\xC0', (10, 36), (0, -2), 12),
            126: FontGlyph(b'\xC0\xC0\x80\x40\x0C\x00\x0C\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x1E\x00\x0C\x00\x0C\x00\x80\x40\xC0\xC0', (10, 15), (0, 0), 12)
        }        