#!/usr/bin/python
# -*- coding:utf-8 -*-

import os

is_raspberry = os.name == 'posix'

if is_raspberry:
    print("Raspberry PI detected.")
    import RPi.GPIO as GPIO
    from epaperOutput import Output
else:
    print("Win10 PC detected.")
    from GPIO_mock import GPIO
    from fileOutput import Output

import sys
import time
import threading
import concurrency

from fonts import FontPrinter,FontRepository
from glyphs import GlyphRepository
from PIL import Image,ImageDraw,ImageFont
import weathermodule

class Display:       
    
    def handleTimerElapsed(self):
        self.module.update()
        self.render()

    def __init__(self):
        self.output = Output()
        self.output.initialize()
        self.module = weathermodule.Module()
        self.lock = threading.Lock()
        self.timer = concurrency.Job(15 * 60, self.handleTimerElapsed)

    def render(self):
        self.lock.acquire()
        try:
            print("Rendering...")
            (blackImage, redImage) = self.module.render()
            self.output.process(blackImage, redImage)
        finally:
            self.lock.release()

    def button_pressed(self, btn):
        print("Button " + str(btn) + " pressed.")

        if btn == 1:
            self.module.switch_mode()
            self.render()

    def handle_channel_change_detected(self, channel):
        if channel == 5:
            self.button_pressed(1)
        elif channel == 6:
            self.button_pressed(2)
        elif channel == 13:
            self.button_pressed(3)
        elif channel == 19:
            self.button_pressed(4)

    def hook_buttons(self):
        GPIO.setup(5, GPIO.IN, pull_up_down=GPIO.PUD_UP)
        GPIO.setup(6, GPIO.IN, pull_up_down=GPIO.PUD_UP)
        GPIO.setup(13, GPIO.IN, pull_up_down=GPIO.PUD_UP)
        GPIO.setup(19, GPIO.IN, pull_up_down=GPIO.PUD_UP)

        GPIO.add_event_detect(5, GPIO.FALLING, callback=self.handle_channel_change_detected, bouncetime=200)
        GPIO.add_event_detect(6, GPIO.FALLING, callback=self.handle_channel_change_detected, bouncetime=200)
        GPIO.add_event_detect(13, GPIO.FALLING, callback=self.handle_channel_change_detected, bouncetime=200)
        GPIO.add_event_detect(19, GPIO.FALLING, callback=self.handle_channel_change_detected, bouncetime=200)

    def unhook_buttons(self):
        GPIO.remove_event_detect(5)
        GPIO.remove_event_detect(6)
        GPIO.remove_event_detect(13)
        GPIO.remove_event_detect(19)

    def run(self):
        self.hook_buttons()
        self.module.update()
        self.render()
        self.timer.start()
        
    def stop(self):
        self.timer.stop()
        self.unhook_buttons()

    def restart(self):
        self.timer.restart()

display = Display()
display.run()

ans = None
while ans != "":
    ans = input("Press Enter to quit or 1, 2, 3, 4 to emulate buttons.\n")
    if ans == '1':
        display.button_pressed(1)
    elif ans == '2':
        display.button_pressed(2)
    elif ans == '3':
        display.button_pressed(3)
    elif ans == '4':
        display.button_pressed(4)

display.stop()