import json
from urllib.request import urlopen
from PIL import Image, ImageDraw
from fonts import FontPrinter, FontRepository
from glyphs import GlyphRepository
from modules import BaseModule
from datetime import datetime
import charts

class Module(BaseModule):

    def __init__(self):
        BaseModule.__init__(self)
        self.weather = None
        self.API_KEY = 'ENTER-YOUR-API-KEY-HERE'
        self.lat = "ENTER-LATITUDE-HERE"
        self.lon = "ENTER-LONGITUDE-HERE"
        self.mode = 0

    def switch_mode(self):
        self.mode = (self.mode + 1) % 3

    def update(self):
        url = 'http://api.openweathermap.org/data/2.5/onecall?lat=' + self.lat + '&lon='+ self.lon + '&units=metric&appid=' + self.API_KEY
        output = urlopen(url).read()
        decoded = output.decode('utf-8')
        self.weather = json.loads(decoded)

    def render_mode0(self):
        black_image = Image.new('1', (self.width, self.height), 255)
        red_image = Image.new('1', (self.width, self.height), 255)
        
        blackDraw = ImageDraw.Draw(black_image)
        redDraw = ImageDraw.Draw(red_image)

        if self.weather["current"]["weather"][0]["icon"] in GlyphRepository.weatherGlyphs:
            GlyphRepository.weatherGlyphs[self.weather["current"]["weather"][0]["icon"]].drawOn(black_image, red_image, (2, 2))
        
        temperature = self.weather["current"]["temp"]
        pressure = self.weather["current"]["pressure"]
        humidity = self.weather["current"]["humidity"]
        windspeed = self.weather["current"]["wind_speed"]

        FontPrinter.print_text(black_image if temperature > 0 else red_image, (84, 8), ("%.1f" % temperature) + "~C", FontRepository.SairaCondensed30)
        FontPrinter.print_text(black_image, (84, 47), str(pressure) + "hPa", FontRepository.SairaCondensed22)
        FontPrinter.print_text(black_image, (195, 13), str(humidity) + "%", FontRepository.SairaCondensed22)
        FontPrinter.print_text(black_image, (195, 47), ("%.0f" % windspeed) + "m/s", FontRepository.SairaCondensed22)

        rain = 0.0
        if "rain" in self.weather["current"]:
            rain = self.weather["current"]["rain"]["1h"]
        clouds = self.weather["current"]["clouds"]
        uv = self.weather["current"]["uvi"]
        visibility = self.weather["current"]["visibility"] / 1000.0

        FontPrinter.print_text(black_image if rain <= 0.0 else red_image, (3, 84), "{%.1fmm" % rain, FontRepository.SairaCondensed11)
        FontPrinter.print_text(black_image, (82, 84), "}%.0f%%" % clouds, FontRepository.SairaCondensed11)
        FontPrinter.print_text(black_image if uv <= 5 else red_image, (140, 84), "|%.1f" % uv, FontRepository.SairaCondensed11)
        FontPrinter.print_text(black_image if visibility >= 10 else red_image, (193, 84), "~%.1fkm" % visibility, FontRepository.SairaCondensed11)

        blackDraw.line([(0, 80),(self.width-1, 80)], fill=0, width=1)
        blackDraw.line([(0, 101),(self.width-1, 101)], fill=0, width=1)

        blackDraw.line([(75, 80), (75, 101)], fill=0, width=1)
        blackDraw.line([(133, 80), (133, 101)], fill=0, width=1)
        blackDraw.line([(187, 80), (187, 101)], fill=0, width=1)

        # Building data for chart

        entries = []
        for hour in self.weather["hourly"]:
            time = datetime.fromtimestamp(hour["dt"] + self.weather["timezone_offset"])
            label = time.strftime("%H")

            entry = charts.SeriesEntry(label, [hour["temp"], hour["rain"]["1h"] if "rain" in hour else 0.0])
            entries.append(entry)

        temp_config = charts.ValueConfig()
        temp_config.axis = 0

        rain_config = charts.ValueConfig()
        rain_config.axis = 1
        rain_config.color = 'r'

        value_configs = [temp_config, rain_config]
        label_config = charts.LabelConfig()

        left_axis_config = charts.AxisConfig()
        left_axis_config.width = 28
        right_axis_config = charts.AxisConfig()
        right_axis_config.color = 'r'
        right_axis_config.use_min = 0.0
        right_axis_config.step = 0.1

        axis_config = [left_axis_config, right_axis_config]
        series = charts.Series(entries, value_configs, label_config, axis_config)
        
        charts.Chart.draw(series, black_image, red_image, (0, 104), (264, 176-104 - 1))

        return (black_image, red_image)

    def render_mode1_pressure_humidity(self, black_image, red_image):
        entries = []
        for hour in self.weather["hourly"]:
            time = datetime.fromtimestamp(hour["dt"] + self.weather["timezone_offset"])
            label = time.strftime("%H")

            entry = charts.SeriesEntry(label, [hour["pressure"], hour["humidity"]])
            entries.append(entry)

        pressure_config = charts.ValueConfig()
        pressure_config.axis = 0

        humidity_config = charts.ValueConfig()
        humidity_config.axis = 1
        humidity_config.color = 'r'

        value_configs = [pressure_config, humidity_config]
        label_config = charts.LabelConfig()

        pressure_axis_config = charts.AxisConfig()
        pressure_axis_config.width = 36
        humidity_axis_config = charts.AxisConfig()
        humidity_axis_config.width = 24
        humidity_axis_config.color = 'r'
        humidity_axis_config.format = "%.0f"
        humidity_axis_config.use_min = 0.0
        humidity_axis_config.use_max = 100.0
        humidity_axis_config.step = 10

        axis_config = [pressure_axis_config, humidity_axis_config]
        series = charts.Series(entries, value_configs, label_config, axis_config)
        
        charts.Chart.draw(series, black_image, red_image, (0, 24), (264, 74))

    def render_mode1_clouds_wind(self, black_image, red_image):
        entries = []
        for hour in self.weather["hourly"]:
            time = datetime.fromtimestamp(hour["dt"] + self.weather["timezone_offset"])
            label = time.strftime("%H")

            entry = charts.SeriesEntry(label, [hour["wind_speed"], hour["clouds"]])
            entries.append(entry)

        wind_config = charts.ValueConfig()
        wind_config.axis = 0

        clouds_config = charts.ValueConfig()
        clouds_config.axis = 1
        clouds_config.color = 'r'

        value_configs = [wind_config, clouds_config]
        label_config = charts.LabelConfig()

        wind_axis_config = charts.AxisConfig()
        wind_axis_config.width = 36
        clouds_axis_config = charts.AxisConfig()
        clouds_axis_config.width = 24
        clouds_axis_config.color = 'r'
        clouds_axis_config.format = "%.0f"
        clouds_axis_config.use_min = 0.0
        clouds_axis_config.use_max = 100.0
        clouds_axis_config.step = 10

        axis_config = [wind_axis_config, clouds_axis_config]
        series = charts.Series(entries, value_configs, label_config, axis_config)
        
        charts.Chart.draw(series, black_image, red_image, (0, 100), (264, 76))

    def render_mode1(self):
        black_image = Image.new('1', (self.width, self.height), 255)
        red_image = Image.new('1', (self.width, self.height), 255)
        
        blackDraw = ImageDraw.Draw(black_image)
        redDraw = ImageDraw.Draw(red_image)

        pos = (4, 4)
        pos = FontPrinter.print_text(black_image, pos, "Pressure, ", FontRepository.SairaCondensed11)
        pos = FontPrinter.print_text(red_image, pos, "humidity", FontRepository.SairaCondensed11)

        pos = (170, 4)
        pos = FontPrinter.print_text(black_image, pos, "Wind, ", FontRepository.SairaCondensed11)
        pos = FontPrinter.print_text(red_image, pos, "clouds", FontRepository.SairaCondensed11)

        self.render_mode1_pressure_humidity(black_image, red_image)
        self.render_mode1_clouds_wind(black_image, red_image)

        return (black_image, red_image)

    def render_day(self, day, target_black_image, target_red_image, position):
        black_image = Image.new('1', (87, 87), 255)
        red_image = Image.new('1', (87, 87), 255)

        black_draw = ImageDraw.Draw(black_image)

        if day["weather"][0]["icon"] in GlyphRepository.weatherGlyphsSmall:
            GlyphRepository.weatherGlyphsSmall[day["weather"][0]["icon"]].drawOn(black_image, red_image, (23, 14))

        # Date

        time = datetime.fromtimestamp(day["dt"] + self.weather["timezone_offset"])
        timeStr = time.strftime("| %d-%m-%Y")
        (textW, _) = FontPrinter.measure(timeStr, FontRepository.SairaCondensed8)
        x = int(87 / 2 - textW / 2)
        FontPrinter.print_text(black_image, (x, 4), timeStr, FontRepository.SairaCondensed8)

        # Temperature

        tempmin = "}"
        tempminvalue = "%.1f*C " % day["temp"]["min"]
        tempmax = "/{ "
        tempmaxvalue = "%.1f*C" % day["temp"]["max"]
        temp = tempmin + tempminvalue + tempmax + tempmaxvalue
        (textW, _) = FontPrinter.measure(temp, FontRepository.SairaCondensed8)
        x = int(87 / 2 - textW / 2)
        pos = (x, 60)
        pos = FontPrinter.print_text(black_image, pos, tempmin, FontRepository.SairaCondensed8)
        pos = FontPrinter.print_text(black_image if day["temp"]["min"] > 0 else red_image, pos, tempminvalue, FontRepository.SairaCondensed8)
        pos = FontPrinter.print_text(black_image, pos, tempmax, FontRepository.SairaCondensed8)
        pos = FontPrinter.print_text(black_image if day["temp"]["max"] > 0 else red_image, pos, tempmaxvalue, FontRepository.SairaCondensed8)

        # Pressure and rain

        pressure = day["pressure"]
        rain = day["rain"] if "rain" in day else 0.0

        pressure_text = "%.1f hPa, " % pressure
        rain_text = "%.1f mm" % rain

        (textW, _) = FontPrinter.measure(pressure_text + rain_text, FontRepository.SairaCondensed8)
        x = int(87 / 2 - textW / 2)
        pos = (x, 74)
        pos = FontPrinter.print_text(black_image, pos, pressure_text, FontRepository.SairaCondensed8)
        pos = FontPrinter.print_text(black_image if rain <= 0.0 else red_image, pos, rain_text, FontRepository.SairaCondensed8)

        target_black_image.paste(black_image, position)
        target_red_image.paste(red_image, position)

    def render_mode2(self):
        black_image = Image.new('1', (self.width, self.height), 255)
        red_image = Image.new('1', (self.width, self.height), 255)
        
        black_draw = ImageDraw.Draw(black_image)
        black_draw.line([(87, 0), (87, 175)], fill = 0, width = 1)
        black_draw.line([(175, 0), (175, 175)], fill = 0, width = 1)
        black_draw.line([(0, 87), (263, 87)], fill = 0, width = 1)

        for i in range(0, 6):
            x = 88 * int(i % 3)
            y = 88 * int(i / 3)

            self.render_day(self.weather["daily"][i], black_image, red_image, (x, y))

        return (black_image, red_image)

    def render(self):
        if self.mode == 0:
            return self.render_mode0()
        elif self.mode == 1:
            return self.render_mode1()
        elif self.mode == 2:
            return self.render_mode2()